summaryrefslogtreecommitdiff
path: root/nova/cmd
diff options
context:
space:
mode:
authorBalazs Gibizer <balazs.gibizer@est.tech>2021-05-14 10:08:35 +0200
committerBalazs Gibizer <balazs.gibizer@est.tech>2021-08-21 10:00:51 +0200
commitf6e8c512fbce7c8ab2444c6a31132dc461f5638b (patch)
tree2de9a663a32c4657f1f8f468db23de8fe4fb096e /nova/cmd
parent9de8bfb6e61ebb9776f8027eb9c334044c7bc8bd (diff)
downloadnova-f6e8c512fbce7c8ab2444c6a31132dc461f5638b.tar.gz
Bump min placement microversion to 1.36
To implement the usage of same_subtree query parameter in the allocation candidate request first the minimum requires placement microversion needs to be bumped from 1.35 to 1.36. This patch makes such bump and update the related nova upgrade check. Later patches will modify the query generation to include the same_subtree param to the request. Change-Id: I5bfec9b9ec49e60c454d71f6fc645038504ef9ef blueprint: qos-minimum-guaranteed-packet-rate
Diffstat (limited to 'nova/cmd')
-rw-r--r--nova/cmd/status.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/nova/cmd/status.py b/nova/cmd/status.py
index 2f14e3fed2..f95a1a4a93 100644
--- a/nova/cmd/status.py
+++ b/nova/cmd/status.py
@@ -49,12 +49,12 @@ from nova.volume import cinder
CONF = nova.conf.CONF
# NOTE(efried): 1.35 is required by nova-scheduler to support the root_required
# queryparam to make GET /allocation_candidates require that a trait be present
# on the root provider, irrespective of how the request groups are specified.
# NOTE: If you bump this version, remember to update the history
# section in the nova-status man page (doc/source/cli/nova-status).
-MIN_PLACEMENT_MICROVERSION = "1.35"
+MIN_PLACEMENT_MICROVERSION = "1.36"
# NOTE(mriedem): 3.44 is needed to work with volume attachment records which
# are required for supporting multi-attach capable volumes.
@@ -49,12 +49,12 @@ from nova.volume import cinder
CONF = nova.conf.CONF
-# NOTE(efried): 1.35 is required by nova-scheduler to support the root_required
-# queryparam to make GET /allocation_candidates require that a trait be present
-# on the root provider, irrespective of how the request groups are specified.
+# NOTE(gibi): 1.36 is required by nova-scheduler to support the same_subtree
+# queryparam to make GET /allocation_candidates require that a list of request
+# groups are satisfied from the same provider subtree.
# NOTE: If you bump this version, remember to update the history
# section in the nova-status man page (doc/source/cli/nova-status).